import { PropsWithChildren } from "react";
import { Store, AnyAction, Action } from "redux";
/** A provider receives a store and children */
export declare type ProviderProps = PropsWithChildren<{
    /** The store object to provide to all nested components */
    store: Store;
}>;
/**
 * The redux store provider
 * @param props store and children
 */
export declare const Provider: ({ store, children }: ProviderProps) => JSX.Element;
/**
 * A hook to access the redux store
 * @throws When a `Provider` is missing.
 */
export declare function useStore<TState = any, TAction extends Action = AnyAction>(): Store<TState, TAction>;
/** Compare by reference */
export declare function compareRef<T>(a: T, b: T): boolean;
/**
 * A hook to use a selector function to access redux state.
 * @param selector  The selector function to retrieve a value from the redux store. It receives the current redux state.
 * @param compare   The comparison function to use in order to only trigger a fresh render when something changed. Default compare by reference.
 * @throws When a `Provider` is missing.
 */
export declare function useSelector<TState = any, TAction extends Action = AnyAction, TResult = any>(selector: (state: TState) => TResult, compare?: (a: TResult, b: TResult) => boolean): TResult;
/**
 * A hook to get the redux stores dispatch function.
 * @throws When a `Provider` is missing.
 */
export declare function useDispatch<TState = any, TAction extends Action = AnyAction>(): import("redux").Dispatch<TAction>;
